#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# This file is part of qmljs, the QML/JS language support plugin for KDevelop
# Copyright (c) 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License or (at your option) version 3 or any later version
# accepted by the membership of KDE e.V. (or its successor approved
# by the membership of KDE e.V.), which shall act as a proxy
# defined in Section 14 of version 3 of the license.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.




from jsgenerator import *
from common import *

# Print the license of the generated file (the same as the one of this file)
license()
basicTypes(globals())
require('buffer')

_object = 'new Object()'

Module().members(
    F(_array, 'getCiphers'),
    F(_array, 'getHashes'),
    F(_object, 'createCredentials', ('details', _object)),
    F('new Hash()', 'createHash', ('algorithm', _string)),
    Class('Hash').members(
        F(_void, 'update', ('data', _string), ('input_encoding', _string)),
        F(_string, 'digest', ('encoding', _string))
    ),
    F('new Hmac()', 'createHmac', ('algorithm', _string), ('key', _string)),
    Class('Hmac').members(
        F(_void, 'update', ('data', _string)),
        F(_string, 'digest', ('encoding', _string))
    ),
    F('new Cipher()', 'createCipher', ('algorithm', _string), ('password', _string)),
    F('new Cipher()', 'createCipheriv', ('algorithm', _string), ('password', _string), ('iv', _string)),
    Class('Cipher').members(
        F(_void, 'update', ('data', _string), ('input_encoding', _string), ('output_encoding', _string)),
        F(_string, 'final', ('output_encoding', _string)),
        F(_void, 'setAutoPadding', ('auto_padding', _bool))
    ),
    F('new Decipher()', 'createDecipher', ('algorithm', _string), ('password', _string)),
    F('new Decipher()', 'createDecipheriv', ('algorithm', _string), ('password', _string), ('iv', _string)),
    Class('Decipher').members(
        F(_void, 'update', ('data', _string), ('input_encoding', _string), ('output_encoding', _string)),
        F(_string, 'final', ('output_encoding', _string)),
        F(_void, 'setAutoPadding', ('auto_padding', _bool))
    ),
    F('new Sign()', 'createSign', ('algorithm', _string)),
    Class('Sign').members(
        F(_void, 'update', ('data', _string)),
        F(_string, 'sign', ('private_key', _string), ('output_format', _string))
    ),
    F('new Verify()', 'createVerify', ('algorithm', _string)),
    Class('Verify').members(
        F(_void, 'update', ('data', _string)),
        F(_bool, 'verify', ('object', _string), ('signature', _string), ('signature_format', _string))
    ),
    F('new DiffieHellman()', 'createDiffieHellman', ('prime_length', _int)),
    Class('DiffieHellman').members(
        F(_string, 'generateKeys', ('encoding', _string)),
        F(_string, 'computeSecret', ('other_public_key', _string), ('input_encoding', _string), ('output_encoding', _string)),
        F(_string, 'getPrime', ('encoding', _string)),
        F(_string, 'getGenerator', ('encoding', _string)),
        F(_string, 'getPublicKey', ('encoding', _string)),
        F(_string, 'getPrivateKey', ('encoding', _string)),
        F(_void, 'setPublicKey', ('public_key', _string), ('encoding', _string)),
        F(_void, 'setPrivateKey', ('private_key', _string), ('encoding', _string)),
    ),
    F('new DiffieHellman()', 'getDiffieHellman', ('group_name', _string)),
    F(_void, 'pbkdf2', ('password', _string), ('salt', _string), ('iterations', _int), ('keylen', _int), ('callback', 'function(){}')),
    F(_string, 'pbkdf2Sync', ('password', _string), ('salt', _string), ('iterations', _int), ('keylen', _int)),
    F('new buffer.Buffer()', 'randomBytes', ('size', _int), ('callback', 'function(){}')),
    F('new buffer.Buffer()', 'pseudoRandomBytes', ('size', _int), ('callback', 'function(){}')),
    Var(_string, 'DEFAULT_ENCODING')
).print()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# This file is part of qmljs, the QML/JS language support plugin for KDevelop
# Copyright (c) 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License or (at your option) version 3 or any later version
# accepted by the membership of KDE e.V. (or its successor approved
# by the membership of KDE e.V.), which shall act as a proxy
# defined in Section 14 of version 3 of the license.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Print the license of the generated file (the same as the one of this file)
def license():
    print("""\
/*
 * This file is part of qmljs, the QML/JS language support plugin for KDevelop
 * Copyright (c) 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
    """)

def basicTypes(d):
    d["_mixed"] = '_mixed'       # This variable does not exist and will therefore yield the type "mixed"
    d["_string"] = '""'
    d["_bool"] = 'true'
    d["_int"] = '1'
    d["_float"] = '1.0'
    d["_array"] = '[]'
    d["_void"] = ''

def require(module):
    print('var %s = require("%s");\n' % (module, module))



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# This file is part of qmljs, the QML/JS language support plugin for KDevelop
# Copyright (c) 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License or (at your option) version 3 or any later version
# accepted by the membership of KDE e.V. (or its successor approved
# by the membership of KDE e.V.), which shall act as a proxy
# defined in Section 14 of version 3 of the license.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.




from jsgenerator import *
from common import *

# Print the license of the generated file (the same as the one of this file)
license()
basicTypes(globals())

Module().members(
    F(_string, 'normalize', ('p', _string)),
    F(_string, 'join', ('path1', _string), ('path2', _string)),
    F(_string, 'resolve', ('path', _string)),
    F(_string, 'relative', ('from', _string), ('to', _string)),
    F(_string, 'dirname', ('p', _string)),
    F(_string, 'basename', ('p', _string), ('ext', _string)),
    F(_string, 'extname', ('p', _string)),
    Var(_string, 'sep'),
    Var(_string, 'delimiter')
).print()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# This file is part of qmljs, the QML/JS language support plugin for KDevelop
# Copyright (c) 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License or (at your option) version 3 or any later version
# accepted by the membership of KDE e.V. (or its successor approved
# by the membership of KDE e.V.), which shall act as a proxy
# defined in Section 14 of version 3 of the license.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.




from jsgenerator import *
from common import *

# Print the license of the generated file (the same as the one of this file)
license()
basicTypes(globals())

_function = 'function(){}'
_object = 'new Object()'

Module().members(
    Class('EventEmitter').members(
        F(_void, 'addListener', ('event', _string), ('listener', _function)),
        F(_void, 'on', ('event', _string), ('listener', _function)),
        F(_void, 'once', ('event', _string), ('listener', _function)),
        F(_void, 'removeListener', ('event', _string), ('listener', _function)),
        F(_void, 'removeAllListeners', ('event', _string)),
        F(_void, 'setMaxListeners', ('n', _int)),
        F(_array, 'listeners', ('event', _string)),
        F(_void, 'emit', ('event', _string), ('args', _mixed)),
        F(_int, 'listenerCount', ('emitter', 'new EventEmitter()'), ('event', _string))
    )
).print()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# This file is part of qmljs, the QML/JS language support plugin for KDevelop
# Copyright (c) 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License or (at your option) version 3 or any later version
# accepted by the membership of KDE e.V. (or its successor approved
# by the membership of KDE e.V.), which shall act as a proxy
# defined in Section 14 of version 3 of the license.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.



from jsgenerator import *

def license():
    # Print the license of the generated file (the same as the one of this file)
    print("""
/*
 * ==== FILE AUTOGENERATED FROM .idl FILES UNDER THE FOLLOWING LICENSE ====
 *
 * Copyright (C) 2008 Apple Inc. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
""")

def get_type(decl):
    typename = ' '.join(decl[0:-1])

    if typename == 'void':
        typename = ''
    elif typename == 'any':
        typename = '_mixed'
    elif typename == 'boolean' or typename == 'bool':
        typename = 'true'
    elif typename == 'DOMString':
        typename = "''"
    elif typename == 'DOMObject':
        typename = 'new Object()'
    elif typename == 'DOMTimeStamp':
        typename = 'new Date()'
    elif 'unsigned' in typename or ' short' in typename or ' int' in typename or ' long' in typename or typename in ['short', 'int', 'long']:
        typename = '1'
    elif typename == 'float' or typename == 'double':
        typename = '1.0'
    elif typename == 'Array':
        typename = '[]'
    elif 'Callback' in typename or 'Handler' in typename:
        typename = 'function(){}'
    elif 'Constructor' in typename:
        typename = typename.replace('Constructor', '')
    else:
        typename = 'new %s()' % typename

    return typename

def get_name(decl):
    return decl[-1]

member_decl = []
param_decl = []
params = []
skip_end_of_line = False
in_module = False
in_interface = False
in_inherit = False
in_param = False
cl = None

def parse(token):
    global member_decl, param_decl, params, skip_end_of_line, in_module, in_interface, in_inherit, in_param, cl

    if token in ['in', 'readonly', 'optional', 'attribute', 'getter', 'setter', '{', '}']:
        pass
    elif token == 'raises':
        skip_end_of_line = True
    elif token == 'module':
        in_module = True
    elif token == 'interface':
        in_module = False
        in_interface = True
    elif in_module:
        # Skip the module declaration
        pass
    elif in_interface:
        # Interface name
        cl = Class(token)
        in_interface = False

        if token == 'DOMWindow':
            # Export window, the only thing that should be exposed to the outside world
            print('module.exports = DOMWindow;')

    elif token == ';':
        # End the current declaration
        if len(member_decl) == 0:
            # When the end of a class is reached, an empty declaration is produced
            cl.print()
            return

        if in_param:
            # Declare a method
            cl.member(F(get_type(member_decl), get_name(member_decl), \
                *[(get_name(p), get_type(p)) for p in params]
            ))
        else:
            # Declare a member variable
            if get_type(member_decl) is not None and get_name(member_decl)[0].isalpha():
                cl.member(Var(get_type(member_decl), get_name(member_decl)))

        member_decl.clear()
        params.clear()
        skip_end_of_line = False
        in_param = False
    elif skip_end_of_line:
        # Skip everything until the colon
        pass
    elif token == ':':
        in_inherit = True
    elif in_inherit:
        cl.prototype(token)
        in_inherit = False
    elif token == '(':
        # Begin the parameter list
        in_param = True
    elif token == ')' or token == ',':
        # End of a parameter
        if len(param_decl) != 0:
            params.append(param_decl[:])
            param_decl.clear()

        pass
    elif in_param:
        # Add a token to the parameter declaration
        param_decl.append(token)
    else:
        # Add a token to the member declaration
        member_decl.append(token)

def tokenize(data):
    token = ''
    prev_c = ''
    c = ''
    next_c = ''
    in_comment = 'none'
    bracket_depth = 0

    for i in range(len(data) + 1):
        prev_c = c
        c = next_c

        if i < len(data):
            next_c = data[i]

        # Handle single-line and multi-line comments
        if in_comment == 'singleline':
            if c == '\n':
                in_comment = 'none'
            continue

        if in_comment == 'multiline':
            if prev_c == '*' and c == '/':
                in_comment = 'none'
            continue

        if c == '/' and next_c == '*':
            in_comment = 'multiline'
            continue

        if c == '/' and next_c == '/':
            in_comment = 'singleline'
            continue

        if c == '#':
            # Skip preprocessor macros: consider them as comments
            in_comment = 'singleline'
            continue

        # Skip hints between brackets
        if c == '[':
            bracket_depth += 1
            continue
        elif c == ']':
            bracket_depth -= 1
            continue

        if bracket_depth > 0:
            continue

        # Spaces are used to separate tokens
        if not c.isalnum() or not token.isalnum():
            if token != '':
                parse(token)
                token = ''

            if c.isspace():
                continue

        token += c

def main():
    license()

    for fl in sys.argv[1:]:
        f = open(fl, 'r')
        tokenize(f.read())
        f.close()

if __name__ == '__main__':
    if len(sys.argv) < 2:
        print('Usage: idltojs.py <idl...>')
    else:
        main()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# This file is part of qmljs, the QML/JS language support plugin for KDevelop
# Copyright (c) 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License or (at your option) version 3 or any later version
# accepted by the membership of KDE e.V. (or its successor approved
# by the membership of KDE e.V.), which shall act as a proxy
# defined in Section 14 of version 3 of the license.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.




from jsgenerator import *
from common import *

# Print the license of the generated file (the same as the one of this file)
license()
basicTypes(globals())

_buffer = 'new Buffer()'

Module().members(
    Class('Buffer', ('size', _int)).members(
        F(_bool, 'isEncoding', ('encoding', _string)),
        F(_void, 'write', ('string', _string), ('offset', _int), ('length', _int), ('encoding', _string)),
        F(_string, 'toJSON'),
        F(_bool, 'isBuffer', ('obj', _buffer)),
        F(_int, 'byteLength', ('string', _string), ('encoding', _string)),
        F(_void, 'concat', ('list', _array), ('totalLength', _int)),
        Var(_int, 'length'),
        F(_void, 'copy', ('target', _buffer), ('targetStart', _int), ('sourceStart', _int), ('sourceEnd', _int)),
        F(_void, 'slice', ('start', _int), ('end', _int)),
        F(_int, 'readUInt8', ('offset', _int), ('noAssert', _bool)),
        F(_int, 'readUInt16LE', ('offset', _int), ('noAssert', _bool)),
        F(_int, 'readUInt16BE', ('offset', _int), ('noAssert', _bool)),
        F(_int, 'readUInt32LE', ('offset', _int), ('noAssert', _bool)),
        F(_int, 'readUInt32BE', ('offset', _int), ('noAssert', _bool)),
        F(_int, 'readInt8', ('offset', _int), ('noAssert', _bool)),
        F(_int, 'readInt16LE', ('offset', _int), ('noAssert', _bool)),
        F(_int, 'readInt16BE', ('offset', _int), ('noAssert', _bool)),
        F(_int, 'readInt32LE', ('offset', _int), ('noAssert', _bool)),
        F(_int, 'readInt32BE', ('offset', _int), ('noAssert', _bool)),
        F(_float, 'readFloatLE', ('offset', _int), ('noAssert', _bool)),
        F(_float, 'readFloatBE', ('offset', _int), ('noAssert', _bool)),
        F(_float, 'readDoubleLE', ('offset', _int), ('noAssert', _bool)),
        F(_float, 'readDoubleBE', ('offset', _int), ('noAssert', _bool)),
        F(_void, 'writeUInt8', ('value', _int), ('offset', _int), ('noAssert', _bool)),
        F(_void, 'writeUInt16LE', ('value', _int), ('offset', _int), ('noAssert', _bool)),
        F(_void, 'writeUInt16BE', ('value', _int), ('offset', _int), ('noAssert', _bool)),
        F(_void, 'writeUInt32LE', ('value', _int), ('offset', _int), ('noAssert', _bool)),
        F(_void, 'writeUInt32BE', ('value', _int), ('offset', _int), ('noAssert', _bool)),
        F(_void, 'writeInt8', ('value', _int), ('offset', _int), ('noAssert', _bool)),
        F(_void, 'writeInt16LE', ('value', _int), ('offset', _int), ('noAssert', _bool)),
        F(_void, 'writeInt16BE', ('value', _int), ('offset', _int), ('noAssert', _bool)),
        F(_void, 'writeInt32LE', ('value', _int), ('offset', _int), ('noAssert', _bool)),
        F(_void, 'writeInt32BE', ('value', _int), ('offset', _int), ('noAssert', _bool)),
        F(_void, 'writeFloatLE', ('value', _float), ('offset', _int), ('noAssert', _bool)),
        F(_void, 'writeFloatBE', ('value', _float), ('offset', _int), ('noAssert', _bool)),
        F(_void, 'writeDoubleLE', ('value', _float), ('offset', _int), ('noAssert', _bool)),
        F(_void, 'writeDoubleBE', ('value', _float), ('offset', _int), ('noAssert', _bool)),
        F(_void, 'fill', ('value', _mixed), ('offset', _int), ('end', _int)),
        Var(_int, 'INSPECT_MAX_BYTES')
    )
).print()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# This file is part of qmljs, the QML/JS language support plugin for KDevelop
# Copyright (c) 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License or (at your option) version 3 or any later version
# accepted by the membership of KDE e.V. (or its successor approved
# by the membership of KDE e.V.), which shall act as a proxy
# defined in Section 14 of version 3 of the license.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.




from jsgenerator import *
from common import *

# Print the license of the generated file (the same as the one of this file)
license()
basicTypes(globals())

_function = 'function(){}'

Module().members(
    F(_void, 'lookup', ('domain', _string), ('family', _int), ('callback', _function)),
    F(_void, 'resolve', ('domain', _string), ('rrtype', _string), ('callback', _function)),
    F(_void, 'resolve4', ('domain', _string), ('callback', _function)),
    F(_void, 'resolve6', ('domain', _string), ('callback', _function)),
    F(_void, 'resolveMx', ('domain', _string), ('callback', _function)),
    F(_void, 'resolveTxt', ('domain', _string), ('callback', _function)),
    F(_void, 'resolveSrv', ('domain', _string), ('callback', _function)),
    F(_void, 'resolveNs', ('domain', _string), ('callback', _function)),
    F(_void, 'resolveCname', ('domain', _string), ('callback', _function)),
    F(_void, 'reverse', ('ip', _string), ('callback', _function)),
    Var(_int, 'NODATA'),
    Var(_int, 'FORMERR'),
    Var(_int, 'SERVFAIL'),
    Var(_int, 'NOTFOUND'),
    Var(_int, 'NOTIMP'),
    Var(_int, 'REFUSED'),
    Var(_int, 'BADQUERY'),
    Var(_int, 'BADNAME'),
    Var(_int, 'BADFAMILY'),
    Var(_int, 'BADRESP'),
    Var(_int, 'CONNREFUSED'),
    Var(_int, 'TIMEOUT'),
    Var(_int, 'EOF'),
    Var(_int, 'FILE'),
    Var(_int, 'NOMEM'),
    Var(_int, 'DESTRUCTION'),
    Var(_int, 'BADSTR'),
    Var(_int, 'BADFLAGS'),
    Var(_int, 'NONAME'),
    Var(_int, 'BADHINTS'),
    Var(_int, 'NOTINITIALIZED'),
    Var(_int, 'LOADIPHLPAPI'),
    Var(_int, 'ADDRGETNETWORKPARAMS'),
    Var(_int, 'CANCELLED')
).print()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# This file is part of qmljs, the QML/JS language support plugin for KDevelop
# Copyright (c) 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License or (at your option) version 3 or any later version
# accepted by the membership of KDE e.V. (or its successor approved
# by the membership of KDE e.V.), which shall act as a proxy
# defined in Section 14 of version 3 of the license.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.




from jsgenerator import *
from common import *

# Print the license of the generated file (the same as the one of this file)
license()
basicTypes(globals())
require('event')

_object = 'new Object()'
_function = 'function(){}'
_address = '{port: 1, family: "", address: ""}'

_peer_certificate = """{
    subject: {C: "", ST: "", L: "", O: "", OU: "", CN: ""},
    issuer: {C: "", ST: "", L: "", O: "", OU: "", CN: ""},
    valid_from: "",
    valid_to: "",
    fingerprint: ""}"""
_cipher = '{name: "", version: ""}'

Module().members(
    F(_array, 'getCiphers'),
    F('new Server()', 'createServer', ('options', _object), ('secureConnectionListener', _function)),
    Var(_int, 'SLAB_BUFFER_SIZE'),
    F('new CleartextStream()', 'connect', ('options', _object), ('callback', _function)),
    F('new SecurePair()', 'createSecurePair', ('credentials', _object), ('isServer', _bool), ('requestCert', _bool), ('rejectUnauthorized', _bool)),
    Class('SecurePair').prototype('event.EventEmitter'),
    Class('Server').prototype('event.EventEmitter').members(
        F(_void, 'listen', ('port', _int), ('host', _string), ('callback', _function)),
        F(_void, 'close'),
        F(_address, 'address'),
        F(_void, 'addContext', ('hostname', _string), ('credentials', _object)),
        Var(_int, 'maxConnections'),
        Var(_int, 'connections')
    ),
    Class('CryptoStream').members(
        Var(_int, 'bytesWritten')
    ),
    Class('CleartextStream').prototype('event.EventEmitter').members(
        Var(_bool, 'authorized'),
        Var(_string, 'authorizationError'),
        F(_peer_certificate, 'getPeerCertificate'),
        F(_cipher, 'getCipher'),
        F(_address, 'address'),
        Var(_string, 'remoteAddress'),
        Var(_int, 'remotePort')
    )
).print()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# This file is part of qmljs, the QML/JS language support plugin for KDevelop
# Copyright (c) 2014 Denis Steckelmacher <steckdenis@yahoo.fr>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License or (at your option) version 3 or any later version
# accepted by the membership of KDE e.V. (or its successor approved
# by the membership of KDE e.V.), which shall act as a proxy
# defined in Section 14 of version 3 of the license.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.




from jsgenerator import *
from common import *

# Print the license of the generated file (the same as the one of this file)
license()
basicTypes(globals())
require('stream')
require('buffer')

_object = 'new Object()'
_function = 'function(){}'
_options = ('options', _object)
_buf = ('buf', 'new buffer.Buffer()')
_callback = ('callback', _function)

Module().members(
    F('new Gzip()', 'createGzip', _options),
    F('new Gunzip()', 'createGunzip', _options),
    F('new Deflate()', 'createDeflate', _options),
    F('new Inflate()', 'createInflate', _options),
    F('new DeflateRaw()', 'createDeflateRaw', _options),
    F('new InflateRaw()', 'createInflateRaw', _options),
    F('new Unzip()', 'createUnzip', _options),
    Class('Zlib').prototype('stream.Duplex').members(
        F(_void, 'flush', ('callback', _function)),
        F(_void, 'reset')
    ),
    Class('Gzip').prototype('exports.Zlib'),
    Class('Gunzip').prototype('exports.Zlib'),
    Class('Deflate').prototype('exports.Zlib'),
    Class('Inflate').prototype('exports.Zlib'),
    Class('DeflateRaw').prototype('exports.Zlib'),
    Class('InflateRaw').prototype('exports.Zlib'),
    Class('Unzip').prototype('exports.Zlib'),
    F(_void, 'deflate', _buf, _callback),
    F(_void, 'deflateRaw', _buf, _callback),
    F(_void, 'gzip', _buf, _callback),
    F(_void, 'gunzip', _buf, _callback),
    F(_void, 'inflate', _buf, _callback),
    F(_void, 'inflateRaw', _buf, _callback),
    F(_void, 'unzip', _buf, _callback)
).print()



#!/usr/bin/env python3

import argparse
import os
import subprocess

# local imports
import create_log

DIR_PATH = os.path.dirname(os.path.realpath(__file__))

def run(fromVersion, toVersion):
    repositories = []
    with open(os.path.join(DIR_PATH, "REPOSITORIES.inc"), 'r') as f:
        repositories = f.read().split()

    for repository in repositories:
        workingDir = os.path.join("..", repository)
        create_log.createLog(workingDir, fromVersion, toVersion)

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description='Create HTML log based on Git history for released KDevelop projects')
    parser.add_argument('from_version', type=str, help='The start of the revision range (e.g. "v5.0.0")')
    parser.add_argument('to_version', type=str, help='The end of the revision range (e.g. "v5.0.1"')
    args = parser.parse_args()

    run(args.from_version, args.to_version)



#
# LLDB data formatters for Qt types
# Copyright 2016 Aetf <aetf@unlimitedcodeworks.xyz>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of
# the License or (at your option) version 3 or any later version
# accepted by the membership of KDE e.V. (or its successor approved
# by the membership of KDE e.V.), which shall act as a proxy
# defined in Section 14 of version 3 of the license.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#


def __lldb_init_module(debugger, unused):
    debugger.HandleCommand('type summary add KDevelop::Path -w kdevelop-kde -F kde.KDevPathSummaryProvider')
    debugger.HandleCommand('type summary add KTextEditor::Cursor -w kdevelop-kde -F kde.KTextEditorCursorSummaryProvider')  # noqa: E501
    debugger.HandleCommand('type summary add KTextEditor::Range -w kdevelop-kde -F kde.KTextEditorRangeSummaryProvider')

    debugger.HandleCommand('type category enable kdevelop-kde')


def KDevPathSummaryProvider(valobj, internal_dict):
    segments = [seg.GetSummary() for seg in valobj.GetChildMemberWithName('m_data')]
    return '(' + ', '.join(segments) + ')' if segments else None


def KTextEditorCursorSummaryProvider(valobj, internal_dict):
    line = valobj.GetChildMemberWithName('m_line').GetValueAsUnsigned(0)
    col = valobj.GetChildMemberWithName('m_column').GetValueAsUnsigned(0)
    return '({}, {})'.format(line, col)


def KTextEditorRangeSummaryProvider(valobj, internal_dict):
    start = valobj.GetChildMemberWithName('m_start')
    end = valobj.GetChildMemberWithName('m_end')

    st_line = start.GetChildMemberWithName('m_line').GetValueAsUnsigned(0)
    st_col = start.GetChildMemberWithName('m_column').GetValueAsUnsigned(0)
    ed_line = end.GetChildMemberWithName('m_line').GetValueAsUnsigned(0)
    ed_col = end.GetChildMemberWithName('m_column').GetValueAsUnsigned(0)
    return '[({}, {}) -> ({}, {})]'.format(st_line, st_col, ed_line, ed_col)
